Package: VOWR
Title: Vital Operational Waiting Risk for Healthcare Systems
Version: 0.1.0
Authors@R: person("Muhammad Zahir", "Khan", 
    email = "zahirstat007@gmail.com", 
    role = c("aut", "cre"), 
    comment = c(ORCID = "0009-0005-7645-8960"))
Description: Vital Operational Waiting Risk (VOWR) provides tools for
    analysing monthly Referral-to-Treatment (RTT) panel data in healthcare
    systems. The package supports provider-level profiling, operational risk
    classification, waiting-time volatility assessment, Kaplan-Meier survival
    analysis, Cox proportional hazards modelling, and visualisation of
    time-to-threshold breach patterns. It is designed to help analysts and
    decision-makers identify providers with high waiting times, unstable
    performance, and increased risk of earlier threshold breach. The survival
    modelling methods follow Cox (1972)
    <doi:10.1111/j.2517-6161.1972.tb00899.x> and Kaplan and Meier (1958)
    <doi:10.1080/01621459.1958.10501452>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: dplyr, ggplot2, survival, stats, utils, survminer
Suggests: testthat (>= 3.0.0),
Config/testthat/edition: 3
URL: https://github.com/zerish12/VOWR
BugReports: https://github.com/zerish12/VOWR/issues
NeedsCompilation: no
Packaged: 2026-05-17 08:24:39 UTC; muhammadzahirkhan
Author: Muhammad Zahir Khan [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-7645-8960>)
Maintainer: Muhammad Zahir Khan <zahirstat007@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-20 09:10:21 UTC
Built: R 4.6.0; ; 2026-05-25 04:44:38 UTC; unix

# Generated by roxygen2: do not edit by hand

export(plot_km_by_delay)
export(vowr_cox_model)
export(vowr_flag)
export(vowr_import)
export(vowr_km_by_risk)
export(vowr_plot)
export(vowr_profile)
export(vowr_survival)
export(vowr_survival_merge)
export(vowr_workflow)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme_minimal)
importFrom(survival,Surv)
importFrom(survival,survfit)
importFrom(utils,read.csv)

<!-- README.md is generated from README.Rmd. Please edit README.Rmd only. -->

# VOWR

## Vital Operational Waiting Risk for Healthcare Systems

<!-- badges: start -->

![R](https://img.shields.io/badge/R-%3E%3D4.0-blue)
![License](https://img.shields.io/badge/license-MIT-green)
![Status](https://img.shields.io/badge/status-active-orange)
![Domain](https://img.shields.io/badge/domain-healthcare%20analytics-red)
<!-- badges: end -->

------------------------------------------------------------------------

## Overview

**VOWR** is an R package for analysing monthly **Referral-to-Treatment
(RTT)** waiting-time data in healthcare systems.

It provides an end-to-end statistical workflow for:

- provider-level performance profiling;
- waiting-time risk classification;
- operational risk visualisation;
- survival analysis of time-to-threshold breach;
- Kaplan-Meier comparison across provider risk groups;
- Cox proportional hazards modelling.

The package is designed for healthcare analysts, applied statisticians,
operational researchers, NHS performance teams, and health-services
researchers.

------------------------------------------------------------------------

## Why VOWR?

Healthcare waiting-time monitoring often relies on static averages. VOWR
extends this by combining **risk profiling**, **volatility detection**,
and **survival-based breach modelling**.

It helps answer questions such as:

- Which providers are stable?
- Which providers are unstable or deteriorating?
- Which providers breach waiting-time thresholds earliest?
- Are risk groups statistically different over time?

------------------------------------------------------------------------

## Installation

During local development, load the package with:

``` r
devtools::load_all()
```

After GitHub release, users will be able to install using:

``` r
# install.packages("devtools")
# devtools::install_github("zerish12/VOWR")
```

------------------------------------------------------------------------

## Required data structure

VOWR expects provider-month RTT data with the following columns:

| Column              | Description                     |
|---------------------|---------------------------------|
| `provider_org_code` | Provider organisation code      |
| `provider_org_name` | Provider organisation name      |
| `period`            | Month/date of observation       |
| `mean_wait_weeks`   | Mean waiting time in weeks      |
| `backlog_total`     | Total backlog                   |
| `bucket_total`      | Total waiting-time bucket count |

------------------------------------------------------------------------

## Quick start

``` r
library(VOWR)

data <- vowr_import()

head(data)
#>   provider_org_code                                       provider_org_name
#> 1             A0C5S                                    SPAMEDICA GLOUCESTER
#> 2               RC9             BEDFORDSHIRE HOSPITALS NHS FOUNDATION TRUST
#> 3               RBV                       THE CHRISTIE NHS FOUNDATION TRUST
#> 4               RBT             MID CHESHIRE HOSPITALS NHS FOUNDATION TRUST
#> 5               RBS               ALDER HEY CHILDREN'S NHS FOUNDATION TRUST
#> 6               RBQ LIVERPOOL HEART AND CHEST HOSPITAL NHS FOUNDATION TRUST
#>       period mean_wait_weeks backlog_total bucket_total
#> 1 01/10/2023        4.871831           950          710
#> 2 01/10/2023       20.628635        276210       239142
#> 3 01/10/2023        6.421240         11966         9294
#> 4 01/10/2023       21.395905        125128       107844
#> 5 01/10/2023       21.765385         71426        64480
#> 6 01/10/2023       15.741076         19338        16584
```

------------------------------------------------------------------------

## Provider profiling

`vowr_profile()` summarises provider-level waiting-time performance.

``` r
profile <- vowr_profile(data)

head(profile)
#> # A tibble: 6 × 7
#>   provider_org_code provider_org_name  n_months mean_wait median_wait volatility
#>   <chr>             <chr>                 <int>     <dbl>       <dbl>      <dbl>
#> 1 8KL73             ENDOCARE DIAGNOST…        3      1.47        1.48      0.106
#> 2 A0C5S             SPAMEDICA GLOUCES…       24      4.77        4.79      0.979
#> 3 A1D1B             SPAMEDICA WEMBLEY         9      4.31        4.86      1.17 
#> 4 A1U4J             SPAMEDICA PORTSMO…       17      4.83        5.10      1.72 
#> 5 A4M8P             BUCKSHAW HOSPITAL        24     15.5        15.4       1.40 
#> 6 A4Q9X             NEWMEDICA LEICEST…       22      3.99        3.16      2.23 
#> # ℹ 1 more variable: total_backlog <int>
```

The output includes:

- number of observed months;
- mean waiting time;
- median waiting time;
- waiting-time volatility;
- total backlog.

------------------------------------------------------------------------

## Risk classification

`vowr_flag()` classifies providers into operational risk groups.

``` r
flagged <- vowr_flag(profile)

table(flagged$risk_flag)
#> 
#> Critical (Breach & Unstable)                High (Breach) 
#>                           21                          114 
#>                       Stable           Warning (Unstable) 
#>                          398                           36
```

Risk groups are defined as:

| Risk group | Meaning |
|----|----|
| `Stable` | Provider is below threshold and not highly volatile |
| `Warning (Unstable)` | Provider is volatile but not currently above threshold |
| `High (Breach)` | Provider is above the waiting-time threshold |
| `Critical (Breach & Unstable)` | Provider is both above threshold and highly volatile |

------------------------------------------------------------------------

## Risk visualisation

`vowr_plot()` produces a provider risk map showing mean waiting time
against volatility.

``` r
risk_plot <- vowr_plot(flagged)

print(risk_plot)
```

<img src="man/figures/README-risk-plot-1.png" alt="" width="100%" />

This plot helps identify providers with high waiting times, high
volatility, or both.

------------------------------------------------------------------------

## Survival analysis

`vowr_survival()` estimates time until a provider first breaches the
waiting-time threshold.

``` r
surv <- vowr_survival(data)

surv$fit
#> Call: survfit(formula = surv_obj ~ 1)
#> 
#>        n events median 0.95LCL 0.95UCL
#> [1,] 551    216     NA      NA      NA

head(surv$surv_data)
#> # A tibble: 6 × 6
#>   provider_org_code start_date end_date   first_breach status time_days
#>   <chr>             <date>     <date>     <date>        <dbl>     <dbl>
#> 1 8KL73             2024-06-01 2024-08-01 NA                0        61
#> 2 A0C5S             2023-10-01 2025-12-01 NA                0       792
#> 3 A1D1B             2025-04-01 2025-12-01 NA                0       244
#> 4 A1U4J             2024-08-01 2025-12-01 NA                0       487
#> 5 A4M8P             2023-10-01 2025-12-01 2023-11-01        1        31
#> 6 A4Q9X             2024-03-01 2025-12-01 NA                0       640
```

The survival output includes:

- provider start date;
- provider end date;
- first breach date;
- breach status;
- time until breach.

------------------------------------------------------------------------

## Kaplan-Meier comparison by risk group

`vowr_survival_merge()` combines survival output with provider profiles
and risk groups.

``` r
surv_profile <- vowr_survival_merge(
  surv_result = surv,
  profile = profile,
  flagged = flagged
)

head(surv_profile)
#> # A tibble: 6 × 13
#>   provider_org_code start_date end_date   first_breach status time_days
#>   <chr>             <date>     <date>     <date>        <dbl>     <dbl>
#> 1 8KL73             2024-06-01 2024-08-01 NA                0        61
#> 2 A0C5S             2023-10-01 2025-12-01 NA                0       792
#> 3 A1D1B             2025-04-01 2025-12-01 NA                0       244
#> 4 A1U4J             2024-08-01 2025-12-01 NA                0       487
#> 5 A4M8P             2023-10-01 2025-12-01 2023-11-01        1        31
#> 6 A4Q9X             2024-03-01 2025-12-01 NA                0       640
#> # ℹ 7 more variables: provider_org_name <chr>, n_months <int>, mean_wait <dbl>,
#> #   median_wait <dbl>, volatility <dbl>, total_backlog <int>, risk_flag <chr>
```

`vowr_km_by_risk()` then produces Kaplan-Meier curves comparing
time-to-breach across risk groups.

``` r
km_plot <- vowr_km_by_risk(surv_profile)

print(km_plot)
```

<img src="man/figures/README-km-risk-plot-1.png" alt="" width="100%" />

This figure assesses whether providers classified into different risk
groups show different breach trajectories.

------------------------------------------------------------------------

## Cox proportional hazards model

`vowr_cox_model()` estimates a Cox proportional hazards model using
provider-level risk indicators.

``` r
cox_fit <- vowr_cox_model(surv_profile)

summary(cox_fit)
#> Call:
#> survival::coxph(formula = survival::Surv(time_days, status) ~ 
#>     mean_wait + volatility + total_backlog, data = model_data)
#> 
#>   n= 607, number of events= 234 
#> 
#>                     coef  exp(coef)   se(coef)      z Pr(>|z|)    
#> mean_wait      2.327e-01  1.262e+00  1.533e-02 15.180  < 2e-16 ***
#> volatility    -3.745e-02  9.632e-01  3.924e-02 -0.954     0.34    
#> total_backlog  1.166e-07  1.000e+00  2.569e-08  4.537 5.71e-06 ***
#> ---
#> Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
#> 
#>               exp(coef) exp(-coef) lower .95 upper .95
#> mean_wait        1.2620     0.7924    1.2246      1.30
#> volatility       0.9632     1.0382    0.8919      1.04
#> total_backlog    1.0000     1.0000    1.0000      1.00
#> 
#> Concordance= 0.92  (se = 0.01 )
#> Likelihood ratio test= 437.8  on 3 df,   p=<2e-16
#> Wald test            = 399  on 3 df,   p=<2e-16
#> Score (logrank) test = 512.8  on 3 df,   p=<2e-16
```

The Cox model supports statistical inference about the association
between provider characteristics and faster threshold breach.

------------------------------------------------------------------------

## One-command workflow

The full pipeline can also be run with `vowr_workflow()`.

``` r
result <- vowr_workflow(data)

names(result)
#> [1] "profile"          "flagged"          "risk_plot"        "survival"        
#> [5] "survival_profile" "cox_model"        "km_risk_plot"
```

The workflow returns:

| Object             | Description                          |
|--------------------|--------------------------------------|
| `profile`          | Provider-level summary table         |
| `flagged`          | Provider profile with risk groups    |
| `risk_plot`        | Risk classification plot             |
| `survival`         | Survival model output                |
| `survival_profile` | Merged survival-profile-risk dataset |
| `cox_model`        | Cox proportional hazards model       |
| `km_risk_plot`     | Kaplan-Meier plot by risk group      |

Example:

``` r
print(result$km_risk_plot)
```

<img src="man/figures/README-workflow-km-1.png" alt="" width="100%" />

``` r
summary(result$cox_model)
#> Call:
#> survival::coxph(formula = survival::Surv(time_days, status) ~ 
#>     mean_wait + volatility + total_backlog, data = model_data)
#> 
#>   n= 607, number of events= 234 
#> 
#>                     coef  exp(coef)   se(coef)      z Pr(>|z|)    
#> mean_wait      2.327e-01  1.262e+00  1.533e-02 15.180  < 2e-16 ***
#> volatility    -3.745e-02  9.632e-01  3.924e-02 -0.954     0.34    
#> total_backlog  1.166e-07  1.000e+00  2.569e-08  4.537 5.71e-06 ***
#> ---
#> Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
#> 
#>               exp(coef) exp(-coef) lower .95 upper .95
#> mean_wait        1.2620     0.7924    1.2246      1.30
#> volatility       0.9632     1.0382    0.8919      1.04
#> total_backlog    1.0000     1.0000    1.0000      1.00
#> 
#> Concordance= 0.92  (se = 0.01 )
#> Likelihood ratio test= 437.8  on 3 df,   p=<2e-16
#> Wald test            = 399  on 3 df,   p=<2e-16
#> Score (logrank) test = 512.8  on 3 df,   p=<2e-16
```

------------------------------------------------------------------------

## Main functions

| Function | Purpose | Output |
|----|----|----|
| `vowr_import()` | Import RTT data | Data frame |
| `vowr_profile()` | Profile provider waiting-time performance | Summary table |
| `vowr_flag()` | Classify providers into risk groups | Risk-labelled table |
| `vowr_plot()` | Visualise provider risk | ggplot object |
| `vowr_survival()` | Estimate threshold-breach survival model | Survival fit and data |
| `vowr_survival_merge()` | Merge survival output with profile and risk flags | Analysis dataset |
| `vowr_km_by_risk()` | Plot Kaplan-Meier curves by risk group | Survival plot |
| `vowr_cox_model()` | Estimate Cox proportional hazards model | Cox model object |
| `vowr_workflow()` | Run the full VOWR pipeline | List of outputs |

------------------------------------------------------------------------

## Interpretation

A typical VOWR analysis may show that:

- stable providers remain below waiting-time thresholds for longer;
- high-risk providers breach earlier;
- critical providers combine high waiting times with high volatility;
- risk groups show different time-to-breach patterns.

This makes VOWR useful for:

- early-warning monitoring;
- provider risk stratification;
- healthcare performance dashboards;
- operational planning;
- reproducible health-services research.

------------------------------------------------------------------------

## Example reporting statement

A VOWR analysis can be summarised as:

> Provider-level waiting-time profiles were constructed from monthly RTT
> panel data. Providers were classified into operational risk groups
> using mean waiting time and volatility. Time-to-threshold breach was
> examined using Kaplan-Meier survival curves and Cox proportional
> hazards models.

------------------------------------------------------------------------

## Development status

Current development status:

- package builds successfully;
- package loads successfully;
- tests pass;
- no errors;
- no warnings;
- core workflow operational.

------------------------------------------------------------------------

## Citation

If you use VOWR in research or applied analysis, please cite:

``` text
Khan MZ. VOWR: Vital Operational Waiting Risk for Healthcare Systems.
R package version 0.1.0.
```

------------------------------------------------------------------------

## Author

**Dr Muhammad Zahir Khan**\
Independent Researcher, United Kingdom\
PhD in Applied Statistics\
Member, Royal Statistical Society

Email: <zahirstat007@gmail.com>\
ORCID: <https://orcid.org/0009-0005-7645-8960>

------------------------------------------------------------------------

## License

This package is released under the **MIT License**.

------------------------------------------------------------------------

## Disclaimer

VOWR is intended for statistical analysis, research, and operational
monitoring. It should support, not replace, expert judgement in
healthcare planning, management, or policy decisions.

#' Kaplan-Meier plot by group
#'
#' @param data A data frame.
#' @param time Name of duration/time variable.
#' @param event Name of event variable: 1 = event occurred, 0 = censored.
#' @param group Name of grouping variable.
#'
#' @return A survminer ggsurvplot object.
#' @export
plot_km_by_delay <- function(data, time, event, group) {

  if (!requireNamespace("survival", quietly = TRUE)) {
    stop("Package 'survival' is required.")
  }

  if (!requireNamespace("survminer", quietly = TRUE)) {
    stop("Package 'survminer' is required.")
  }

  plot_data <- data.frame(
    time_var  = data[[time]],
    event_var = data[[event]],
    group_var = as.factor(data[[group]])
  )

  fit <- survival::survfit(
    survival::Surv(time_var, event_var) ~ group_var,
    data = plot_data
  )

  survminer::ggsurvplot(
    fit,
    data = plot_data,
    risk.table = TRUE,
    conf.int = TRUE,
    pval = TRUE,
    legend.title = "Group",
    legend.labs = levels(plot_data$group_var),
    xlab = "Days until threshold breach",
    ylab = "Probability of remaining below threshold"
  )
}

#' Estimate Cox proportional hazards model for threshold breach
#'
#' @param surv_profile Data frame from vowr_survival_merge()
#' @return A fitted Cox proportional hazards model
#' @export
vowr_cox_model <- function(surv_profile) {

  required <- c("time_days", "status", "mean_wait", "volatility", "total_backlog")

  missing_cols <- setdiff(required, names(surv_profile))

  if (length(missing_cols) > 0) {
    stop(
      "Missing required columns: ",
      paste(missing_cols, collapse = ", ")
    )
  }

  model_data <- stats::na.omit(
    surv_profile[, required]
  )

  fit <- survival::coxph(
    survival::Surv(time_days, status) ~ mean_wait + volatility + total_backlog,
    data = model_data
  )

  return(fit)
}

#' Flag high-risk providers
#'
#' @param profile A data frame produced by vowr_profile()
#' @param wait_threshold The mean wait time threshold (default 18 weeks)
#' @param vol_percentile The percentile for volatility (default 0.90)
#' @return The profile data frame with a 'risk_flag' column
#' @export
vowr_flag <- function(profile, wait_threshold = 18, vol_percentile = 0.90) {

  vol_cutoff <- stats::quantile(profile$volatility, vol_percentile, na.rm = TRUE)

  profile$is_breach <- profile$mean_wait > wait_threshold
  profile$is_volatile <- profile$volatility > vol_cutoff

  profile$risk_flag <- dplyr::case_when(
    profile$is_breach & profile$is_volatile ~ "Critical (Breach & Unstable)",
    profile$is_breach                       ~ "High (Breach)",
    profile$is_volatile                     ~ "Warning (Unstable)",
    TRUE                                    ~ "Stable"
  )

  profile <- dplyr::select(profile, -is_breach, -is_volatile)

  return(profile)
}

#' Profile National Health Service provider performance
#'
#' @param data A data frame from vowr_import().
#'
#' @return A summary table with the number of months, mean waiting time,
#' median waiting time, waiting-time volatility, and total backlog for each
#' provider.
#'
#' @export
vowr_profile <- function(data) {
  profile <- dplyr::group_by(data, provider_org_code, provider_org_name)

  profile <- dplyr::summarise(
    profile,
    n_months      = dplyr::n(),
    mean_wait     = base::mean(mean_wait_weeks, na.rm = TRUE),
    median_wait   = stats::median(mean_wait_weeks, na.rm = TRUE),
    volatility    = stats::sd(mean_wait_weeks, na.rm = TRUE),
    total_backlog = base::sum(backlog_total, na.rm = TRUE),
    .groups       = "drop"
  )

  return(profile)
}

test_that("vowr_profile returns expected dimensions", {

  # 1. DEFINE the dummy data INSIDE the test block
  dummy_data <- data.frame(
    provider_org_code = c("A", "A", "B"),
    provider_org_name = c("Org A", "Org A", "Org B"),
    mean_wait_weeks = c(10, 12, 18),
    backlog_total = c(100, 200, 300)
  )

  # 2. CALL your function using that dummy_data
  result <- vowr_profile(dummy_data)

  # 3. CHECK expectations
  expect_equal(nrow(result), 2)
  expect_equal(ncol(result), 7)
})

#' Merge survival output with provider profile and risk flags
#'
#' @param surv_result Output from vowr_survival()
#' @param profile Output from vowr_profile()
#' @param flagged Output from vowr_flag()
#' @return A provider-level survival analysis data frame
#' @export
vowr_survival_merge <- function(surv_result, profile, flagged) {

  surv_data <- surv_result$surv_data

  profile_keep <- profile[, c(
    "provider_org_code",
    "provider_org_name",
    "n_months",
    "mean_wait",
    "median_wait",
    "volatility",
    "total_backlog"
  )]

  flagged_keep <- flagged[, c(
    "provider_org_code",
    "risk_flag"
  )]

  out <- dplyr::left_join(
    surv_data,
    profile_keep,
    by = "provider_org_code"
  )

  out <- dplyr::left_join(
    out,
    flagged_keep,
    by = "provider_org_code"
  )

  return(out)
}

#' Kaplan-Meier plot by provider risk group
#'
#' @param surv_profile Data frame from vowr_survival_merge()
#' @return A survminer Kaplan-Meier plot object
#' @export
vowr_km_by_risk <- function(surv_profile) {

  required <- c("time_days", "status", "risk_flag")
  missing_cols <- setdiff(required, names(surv_profile))

  if (length(missing_cols) > 0) {
    stop("Missing required columns: ", paste(missing_cols, collapse = ", "))
  }

  plot_data <- surv_profile[!is.na(surv_profile$risk_flag), ]

  plot_data$risk_group <- dplyr::case_when(
    plot_data$risk_flag == "Critical (Breach & Unstable)" ~ "Critical",
    plot_data$risk_flag == "High (Breach)" ~ "High",
    plot_data$risk_flag == "Warning (Unstable)" ~ "Warning",
    plot_data$risk_flag == "Stable" ~ "Stable",
    TRUE ~ as.character(plot_data$risk_flag)
  )

  plot_data$risk_group <- factor(
    plot_data$risk_group,
    levels = c("Stable", "Warning", "High", "Critical")
  )

  fit <- survival::survfit(
    survival::Surv(time_days, status) ~ risk_group,
    data = plot_data
  )

  survminer::ggsurvplot(
    fit,
    data = plot_data,
    risk.table = FALSE,
    conf.int = FALSE,
    pval = TRUE,
    pval.coord = c(45, 0.18),
    legend.title = "Risk group",
    legend.labs = c("Stable", "Warning", "High", "Critical"),
    xlab = "Days until threshold breach",
    ylab = "Probability of remaining below threshold",
    break.time.by = 200,
    censor.shape = "|",
    censor.size = 3,
    linewidth = 1.1,
    ggtheme = ggplot2::theme_minimal(base_size = 14) +
      ggplot2::theme(
        legend.position = "top",
        legend.title = ggplot2::element_text(face = "bold"),
        plot.title = ggplot2::element_text(face = "bold", hjust = 0.5),
        axis.title = ggplot2::element_text(face = "bold"),
        panel.grid.minor = ggplot2::element_blank()
      )
  )
}

#' Import and validate RTT data
#'
#' @param path Optional path to an NHS Referral-to-Treatment (RTT) CSV file.
#' If NULL, the example data included in the package is loaded.
#'
#' @return A cleaned data frame.
#' @importFrom utils read.csv
#'
#' @examples
#' sample_path <- system.file(
#'   "extdata",
#'   "rtt_trust_month_panel_last24_FIXED-2.csv",
#'   package = "VOWR"
#' )
#'
#' data <- vowr_import(sample_path)
#' head(data)
#'
#' @export
vowr_import <- function(path = NULL) {

  if (is.null(path)) {
    path <- system.file(
      "extdata",
      "rtt_trust_month_panel_last24_FIXED-2.csv",
      package = "VOWR"
    )
  }

  if (path == "") {
    stop("File not found. Please check the file path or inst/extdata folder.")
  }

  data <- utils::read.csv(path, stringsAsFactors = FALSE)

  return(data)
}

utils::globalVariables(c(
  "provider_org_code",
  "provider_org_name",
  "mean_wait_weeks",
  "backlog_total",
  "period",
  "first_breach",
  "start_date",
  "end_date",
  "mean_wait",
  "volatility",
  "risk_flag",
  "is_breach",
  "is_volatile"
))

#' Estimate time-to-breach survival model
#'
#' @param data A data frame from vowr_import().
#' @param threshold Mean waiting-time threshold in weeks. Default is 18.
#'
#' @return A list containing a Kaplan-Meier survival model object and the data
#' used to fit the model.
#'
#' @importFrom survival Surv survfit
#' @importFrom dplyr group_by summarise mutate filter left_join
#' @export
vowr_survival <- function(data, threshold = 18) {

  # Ensure period is in Date format
  data$period <- as.Date(data$period, format = "%d/%m/%Y")

  # 1. Identify first month of breach for each provider
  breach_data <- dplyr::filter(data, mean_wait_weeks > threshold)
  breach_data <- dplyr::group_by(breach_data, provider_org_code)
  breach_data <- dplyr::summarise(
    breach_data,
    first_breach = min(period, na.rm = TRUE),
    .groups = "drop"
  )

  # 2. Get start/end dates for each provider
  censoring_data <- dplyr::group_by(data, provider_org_code)
  censoring_data <- dplyr::summarise(
    censoring_data,
    start_date = min(period, na.rm = TRUE),
    end_date = max(period, na.rm = TRUE),
    .groups = "drop"
  )

  # 3. Join and create survival object
  surv_input <- dplyr::left_join(censoring_data, breach_data, by = "provider_org_code")
  surv_input <- dplyr::mutate(
    surv_input,
    status = ifelse(is.na(first_breach), 0, 1),
    time_days = ifelse(
      is.na(first_breach),
      as.numeric(end_date - start_date),
      as.numeric(first_breach - start_date)
    )
  )

  # 4. Fit survival model using Kaplan-Meier method
  surv_obj <- survival::Surv(time = surv_input$time_days, event = surv_input$status)
  fit <- survival::survfit(surv_obj ~ 1)

  return(list(fit = fit, surv_data = surv_input))
}

#' Run complete Volatility-Oriented Waiting-time Risk workflow
#'
#' @param data A data frame from vowr_import()
#' @param wait_threshold Waiting-time breach threshold. Default is 18 weeks.
#' @param vol_percentile Volatility percentile for risk flagging. Default is 0.90.
#'
#' @return A list containing profile, flagged data, risk plot, survival output,
#' survival profile, Cox model, and Kaplan-Meier plot by risk group.
#'
#' @export
vowr_workflow <- function(data, wait_threshold = 18, vol_percentile = 0.90) {

  profile <- vowr_profile(data)

  flagged <- vowr_flag(
    profile = profile,
    wait_threshold = wait_threshold,
    vol_percentile = vol_percentile
  )

  risk_plot <- vowr_plot(flagged)

  survival <- vowr_survival(
    data = data,
    threshold = wait_threshold
  )

  survival_profile <- vowr_survival_merge(
    surv_result = survival,
    profile = profile,
    flagged = flagged
  )

  cox_model <- vowr_cox_model(survival_profile)

  km_risk_plot <- vowr_km_by_risk(survival_profile)

  return(list(
    profile = profile,
    flagged = flagged,
    risk_plot = risk_plot,
    survival = survival,
    survival_profile = survival_profile,
    cox_model = cox_model,
    km_risk_plot = km_risk_plot
  ))
}

#' Visualize provider risk distribution
#'
#' @param flagged_data A data frame produced by vowr_flag()
#' @return A ggplot object
#' @importFrom ggplot2 ggplot aes geom_point scale_color_manual theme_minimal labs geom_vline geom_hline
#' @export

vowr_plot <- function(flagged_data) {
  p <- ggplot2::ggplot(flagged_data, ggplot2::aes(x = mean_wait, y = volatility, color = risk_flag)) +
    ggplot2::geom_point(alpha = 0.6, size = 2) +
    ggplot2::scale_color_manual(values = c(
      "Critical (Breach & Unstable)" = "red",
      "High (Breach)" = "orange",
      "Warning (Unstable)" = "blue",
      "Stable" = "darkgreen"
    )) +
    ggplot2::geom_vline(xintercept = 18, linetype = "dashed", color = "gray50") +
    ggplot2::theme_minimal() +
    ggplot2::labs(
      title = "NHS Provider Risk Classification",
      x = "Mean Waiting Time (Weeks)",
      y = "Performance Volatility (SD)",
      color = "Risk Category"
    )

  return(p)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_cox_model.R
\name{vowr_cox_model}
\alias{vowr_cox_model}
\title{Estimate Cox proportional hazards model for threshold breach}
\usage{
vowr_cox_model(surv_profile)
}
\arguments{
\item{surv_profile}{Data frame from vowr_survival_merge()}
}
\value{
A fitted Cox proportional hazards model
}
\description{
Estimate Cox proportional hazards model for threshold breach
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_plot.R
\name{vowr_plot}
\alias{vowr_plot}
\title{Visualize provider risk distribution}
\usage{
vowr_plot(flagged_data)
}
\arguments{
\item{flagged_data}{A data frame produced by vowr_flag()}
}
\value{
A ggplot object
}
\description{
Visualize provider risk distribution
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_profile.R
\name{vowr_profile}
\alias{vowr_profile}
\title{Profile National Health Service provider performance}
\usage{
vowr_profile(data)
}
\arguments{
\item{data}{A data frame from vowr_import().}
}
\value{
A summary table with the number of months, mean waiting time,
median waiting time, waiting-time volatility, and total backlog for each
provider.
}
\description{
Profile National Health Service provider performance
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_import.R
\name{vowr_import}
\alias{vowr_import}
\title{Import and validate RTT data}
\usage{
vowr_import(path = NULL)
}
\arguments{
\item{path}{Optional path to an NHS Referral-to-Treatment (RTT) CSV file.
If NULL, the example data included in the package is loaded.}
}
\value{
A cleaned data frame.
}
\description{
Import and validate RTT data
}
\examples{
sample_path <- system.file(
  "extdata",
  "rtt_trust_month_panel_last24_FIXED-2.csv",
  package = "VOWR"
)

data <- vowr_import(sample_path)
head(data)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_survival_merge.R
\name{vowr_survival_merge}
\alias{vowr_survival_merge}
\title{Merge survival output with provider profile and risk flags}
\usage{
vowr_survival_merge(surv_result, profile, flagged)
}
\arguments{
\item{surv_result}{Output from vowr_survival()}

\item{profile}{Output from vowr_profile()}

\item{flagged}{Output from vowr_flag()}
}
\value{
A provider-level survival analysis data frame
}
\description{
Merge survival output with provider profile and risk flags
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/survival_plots.R
\name{plot_km_by_delay}
\alias{plot_km_by_delay}
\title{Kaplan-Meier plot by group}
\usage{
plot_km_by_delay(data, time, event, group)
}
\arguments{
\item{data}{A data frame.}

\item{time}{Name of duration/time variable.}

\item{event}{Name of event variable: 1 = event occurred, 0 = censored.}

\item{group}{Name of grouping variable.}
}
\value{
A survminer ggsurvplot object.
}
\description{
Kaplan-Meier plot by group
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_survival.R
\name{vowr_survival}
\alias{vowr_survival}
\title{Estimate time-to-breach survival model}
\usage{
vowr_survival(data, threshold = 18)
}
\arguments{
\item{data}{A data frame from vowr_import().}

\item{threshold}{Mean waiting-time threshold in weeks. Default is 18.}
}
\value{
A list containing a Kaplan-Meier survival model object and the data
used to fit the model.
}
\description{
Estimate time-to-breach survival model
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_flag.R
\name{vowr_flag}
\alias{vowr_flag}
\title{Flag high-risk providers}
\usage{
vowr_flag(profile, wait_threshold = 18, vol_percentile = 0.9)
}
\arguments{
\item{profile}{A data frame produced by vowr_profile()}

\item{wait_threshold}{The mean wait time threshold (default 18 weeks)}

\item{vol_percentile}{The percentile for volatility (default 0.90)}
}
\value{
The profile data frame with a 'risk_flag' column
}
\description{
Flag high-risk providers
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_workflow.R
\name{vowr_workflow}
\alias{vowr_workflow}
\title{Run complete Volatility-Oriented Waiting-time Risk workflow}
\usage{
vowr_workflow(data, wait_threshold = 18, vol_percentile = 0.9)
}
\arguments{
\item{data}{A data frame from vowr_import()}

\item{wait_threshold}{Waiting-time breach threshold. Default is 18 weeks.}

\item{vol_percentile}{Volatility percentile for risk flagging. Default is 0.90.}
}
\value{
A list containing profile, flagged data, risk plot, survival output,
survival profile, Cox model, and Kaplan-Meier plot by risk group.
}
\description{
Run complete Volatility-Oriented Waiting-time Risk workflow
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_km_by_risk.R
\name{vowr_km_by_risk}
\alias{vowr_km_by_risk}
\title{Kaplan-Meier plot by provider risk group}
\usage{
vowr_km_by_risk(surv_profile)
}
\arguments{
\item{surv_profile}{Data frame from vowr_survival_merge()}
}
\value{
A survminer Kaplan-Meier plot object
}
\description{
Kaplan-Meier plot by provider risk group
}
